/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.base;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.IConstraintChecker;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;

/**
 * Base implementation for {@link IConstraintViolation} produced by model
 * element {@link IConstraintChecker}s. It stores the violating model element
 * and returns <code>null</code> as quick fix handler.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 5968B8078503BFB90E32F041A5BD160C
 */
public abstract class ConstraintViolationBase<T extends EObject> implements
		IConstraintViolation<T> {

	/** Stores the model element. */
	private final T source;

	/** Constructor. */
	public ConstraintViolationBase(T source) {
		this.source = source;
	}

	/** {@inheritDoc} */
	@Override
	public T getSource() {
		return source;
	}

	/** {@inheritDoc} */
	@Override
	public IQuickFixHandler getQuickFixHandler() {
		return null;
	}
}
